from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Graphics.Printing
import win32more.Windows.Graphics.Printing.OptionDetails
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class IPrintBindingOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintBindingOptionDetails'
    _iid_ = Guid('{c3f4cc98-9564-4f16-a055-a98b9a49e9d3}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintBorderingOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintBorderingOptionDetails'
    _iid_ = Guid('{4d73bc8f-fb53-4eb2-985f-1d91de0b7639}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintCollationOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintCollationOptionDetails'
    _iid_ = Guid('{d6abb166-a5a6-40dc-acc3-739f28f1e5d3}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintColorModeOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintColorModeOptionDetails'
    _iid_ = Guid('{dba97704-f1d6-4843-a484-9b447cdcf3b6}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintCopiesOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintCopiesOptionDetails'
    _iid_ = Guid('{42053099-4339-4343-898d-2c47b5e0c341}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintCustomItemDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintCustomItemDetails'
    _iid_ = Guid('{5704b637-5c3a-449a-aa36-b3291b1192fd}')
    @winrt_commethod(6)
    def get_ItemId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_ItemDisplayName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_ItemDisplayName(self) -> WinRT_String: ...
    ItemDisplayName = property(get_ItemDisplayName, put_ItemDisplayName)
    ItemId = property(get_ItemId, None)
class IPrintCustomItemListOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintCustomItemListOptionDetails'
    _iid_ = Guid('{a5fafd88-58f2-4ebd-b90f-51e4f2944c5d}')
    @winrt_commethod(6)
    def AddItem(self, itemId: WinRT_String, displayName: WinRT_String) -> Void: ...
class IPrintCustomItemListOptionDetails2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintCustomItemListOptionDetails2'
    _iid_ = Guid('{c9d6353d-651c-4a39-906e-1091a1801bf1}')
    @winrt_commethod(6)
    def AddItem(self, itemId: WinRT_String, displayName: WinRT_String, description: WinRT_String, icon: win32more.Windows.Storage.Streams.IRandomAccessStreamWithContentType) -> Void: ...
class IPrintCustomItemListOptionDetails3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintCustomItemListOptionDetails3'
    _iid_ = Guid('{4fa1b53f-3c34-4868-a407-fc5eab259b21}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintCustomOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintCustomOptionDetails'
    _iid_ = Guid('{e32bde1c-28af-4b90-95da-a3acf320b929}')
    @winrt_commethod(6)
    def put_DisplayName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_DisplayName(self) -> WinRT_String: ...
    DisplayName = property(get_DisplayName, put_DisplayName)
class IPrintCustomTextOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintCustomTextOptionDetails'
    _iid_ = Guid('{2ad171f8-c8bd-4905-9192-0d75136e8b31}')
    @winrt_commethod(6)
    def put_MaxCharacters(self, value: UInt32) -> Void: ...
    @winrt_commethod(7)
    def get_MaxCharacters(self) -> UInt32: ...
    MaxCharacters = property(get_MaxCharacters, put_MaxCharacters)
class IPrintCustomTextOptionDetails2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintCustomTextOptionDetails2'
    _iid_ = Guid('{cea70b54-b977-4718-8338-7ed2b0d86fe3}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintCustomToggleOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintCustomToggleOptionDetails'
    _iid_ = Guid('{9db4d514-e461-4608-8ee9-db6f5ed073c6}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintDuplexOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintDuplexOptionDetails'
    _iid_ = Guid('{fcd94591-d4a4-44fa-b3fe-42e0ba28d5ad}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintHolePunchOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintHolePunchOptionDetails'
    _iid_ = Guid('{a6de1f18-482c-4657-9d71-8ddddbea1e1e}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintItemListOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails'
    _iid_ = Guid('{9a2257bf-fe61-43d8-a24f-a3f6ab7320e7}')
    @winrt_commethod(6)
    def get_Items(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    Items = property(get_Items, None)
class IPrintMediaSizeOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintMediaSizeOptionDetails'
    _iid_ = Guid('{6c8d5bcf-c0bf-47c8-b84a-628e7d0d1a1d}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintMediaTypeOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintMediaTypeOptionDetails'
    _iid_ = Guid('{f8c7000b-abf3-4abc-8e86-22abc5744a43}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintNumberOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintNumberOptionDetails'
    _iid_ = Guid('{4d01bbaf-645c-4de9-965f-6fc6bbc47cab}')
    @winrt_commethod(6)
    def get_MinValue(self) -> UInt32: ...
    @winrt_commethod(7)
    def get_MaxValue(self) -> UInt32: ...
    MaxValue = property(get_MaxValue, None)
    MinValue = property(get_MinValue, None)
class IPrintOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails'
    _iid_ = Guid('{390686cf-d682-495f-adfe-d7333f5c1808}')
    @winrt_commethod(6)
    def get_OptionId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_OptionType(self) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_commethod(8)
    def put_ErrorText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_ErrorText(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def put_State(self, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_commethod(11)
    def get_State(self) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_commethod(12)
    def get_Value(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(13)
    def TrySetValue(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    ErrorText = property(get_ErrorText, put_ErrorText)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
class IPrintOrientationOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintOrientationOptionDetails'
    _iid_ = Guid('{46c38879-66e0-4da0-87b4-d25457824eb7}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintPageRangeOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintPageRangeOptionDetails'
    _iid_ = Guid('{5a19e4b7-2be8-4aa7-9ea5-defbe8713b4e}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintQualityOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintQualityOptionDetails'
    _iid_ = Guid('{2dd06ba1-ce1a-44e6-84f9-3a92ea1e3044}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintStapleOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintStapleOptionDetails'
    _iid_ = Guid('{d43175bd-9c0b-44e0-84f6-ceebce653800}')
    @winrt_commethod(6)
    def put_WarningText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def get_WarningText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    WarningText = property(get_WarningText, put_WarningText)
class IPrintTaskOptionChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionChangedEventArgs'
    _iid_ = Guid('{65197d05-a5ee-4307-9407-9acad147679c}')
    @winrt_commethod(6)
    def get_OptionId(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    OptionId = property(get_OptionId, None)
class IPrintTaskOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetails'
    _iid_ = Guid('{f5720af1-a89e-42a6-81af-f8e010b38a68}')
    @winrt_commethod(6)
    def get_Options(self) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails]: ...
    @winrt_commethod(7)
    def CreateItemListOption(self, optionId: WinRT_String, displayName: WinRT_String) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintCustomItemListOptionDetails: ...
    @winrt_commethod(8)
    def CreateTextOption(self, optionId: WinRT_String, displayName: WinRT_String) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintCustomTextOptionDetails: ...
    @winrt_commethod(9)
    def add_OptionChanged(self, eventHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Printing.OptionDetails.PrintTaskOptionDetails, win32more.Windows.Graphics.Printing.OptionDetails.PrintTaskOptionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_OptionChanged(self, eventCookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(11)
    def add_BeginValidation(self, eventHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Printing.OptionDetails.PrintTaskOptionDetails, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(12)
    def remove_BeginValidation(self, eventCookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Options = property(get_Options, None)
    OptionChanged = event()
    BeginValidation = event()
class IPrintTaskOptionDetails2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetails2'
    _iid_ = Guid('{53730a09-f968-4692-a177-c074597186db}')
    @winrt_commethod(6)
    def CreateToggleOption(self, optionId: WinRT_String, displayName: WinRT_String) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintCustomToggleOptionDetails: ...
class IPrintTaskOptionDetailsStatic(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetailsStatic'
    _iid_ = Guid('{135da193-0961-4b6e-8766-f13b7fbccd58}')
    @winrt_commethod(6)
    def GetFromPrintTaskOptions(self, printTaskOptions: win32more.Windows.Graphics.Printing.PrintTaskOptions) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintTaskOptionDetails: ...
class IPrintTextOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.IPrintTextOptionDetails'
    _iid_ = Guid('{ad75e563-5ce4-46bc-9918-ab9fad144c5b}')
    @winrt_commethod(6)
    def get_MaxCharacters(self) -> UInt32: ...
    MaxCharacters = property(get_MaxCharacters, None)
class PrintBindingOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintBindingOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintBindingOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintBindingOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintBindingOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintBindingOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintBorderingOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintBorderingOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintBorderingOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintBorderingOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintBorderingOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintBorderingOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintCollationOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintCollationOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCollationOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCollationOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCollationOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCollationOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintColorModeOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintColorModeOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintColorModeOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintColorModeOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintColorModeOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintColorModeOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintCopiesOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintCopiesOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_MinValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintNumberOptionDetails) -> UInt32: ...
    @winrt_mixinmethod
    def get_MaxValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintNumberOptionDetails) -> UInt32: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCopiesOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCopiesOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCopiesOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCopiesOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    MaxValue = property(get_MaxValue, None)
    MinValue = property(get_MinValue, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintCustomItemDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomItemDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintCustomItemDetails'
    @winrt_mixinmethod
    def get_ItemId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomItemDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_ItemDisplayName(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomItemDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ItemDisplayName(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomItemDetails) -> WinRT_String: ...
    ItemDisplayName = property(get_ItemDisplayName, put_ItemDisplayName)
    ItemId = property(get_ItemId, None)
class PrintCustomItemListOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintCustomItemListOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def put_DisplayName(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_overload
    @winrt_mixinmethod
    def AddItem(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomItemListOptionDetails, itemId: WinRT_String, displayName: WinRT_String) -> Void: ...
    @AddItem.register
    @winrt_mixinmethod
    def AddItem(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomItemListOptionDetails2, itemId: WinRT_String, displayName: WinRT_String, description: WinRT_String, icon: win32more.Windows.Storage.Streams.IRandomAccessStreamWithContentType) -> Void: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomItemListOptionDetails3, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomItemListOptionDetails3) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomItemListOptionDetails3, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomItemListOptionDetails3) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    DisplayName = property(get_DisplayName, put_DisplayName)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintCustomTextOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintCustomTextOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def put_DisplayName(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_MaxCharacters(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomTextOptionDetails, value: UInt32) -> Void: ...
    @winrt_mixinmethod
    def get_MaxCharacters(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomTextOptionDetails) -> UInt32: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomTextOptionDetails2, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomTextOptionDetails2) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomTextOptionDetails2, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomTextOptionDetails2) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    DisplayName = property(get_DisplayName, put_DisplayName)
    ErrorText = property(get_ErrorText, put_ErrorText)
    MaxCharacters = property(get_MaxCharacters, put_MaxCharacters)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintCustomToggleOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintCustomToggleOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def put_DisplayName(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomToggleOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomToggleOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomToggleOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintCustomToggleOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    DisplayName = property(get_DisplayName, put_DisplayName)
    ErrorText = property(get_ErrorText, put_ErrorText)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintDuplexOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintDuplexOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintDuplexOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintDuplexOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintDuplexOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintDuplexOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintHolePunchOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintHolePunchOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintHolePunchOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintHolePunchOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintHolePunchOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintHolePunchOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintMediaSizeOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintMediaSizeOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintMediaSizeOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintMediaSizeOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintMediaSizeOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintMediaSizeOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintMediaTypeOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintMediaTypeOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintMediaTypeOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintMediaTypeOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintMediaTypeOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintMediaTypeOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintOptionStates(Enum, UInt32):
    None_ = 0
    Enabled = 1
    Constrained = 2
class PrintOptionType(Enum, Int32):
    Unknown = 0
    Number = 1
    Text = 2
    ItemList = 3
    Toggle = 4
class PrintOrientationOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintOrientationOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOrientationOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOrientationOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOrientationOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOrientationOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintPageRangeOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintPageRangeOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintPageRangeOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintPageRangeOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintPageRangeOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintPageRangeOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintQualityOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintQualityOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintQualityOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintQualityOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintQualityOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintQualityOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintStapleOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintStapleOptionDetails'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_OptionType(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionType: ...
    @winrt_mixinmethod
    def put_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ErrorText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintOptionStates: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def TrySetValue(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintItemListOptionDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def put_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintStapleOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_WarningText(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintStapleOptionDetails) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintStapleOptionDetails, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintStapleOptionDetails) -> WinRT_String: ...
    Description = property(get_Description, put_Description)
    ErrorText = property(get_ErrorText, put_ErrorText)
    Items = property(get_Items, None)
    OptionId = property(get_OptionId, None)
    OptionType = property(get_OptionType, None)
    State = property(get_State, put_State)
    Value = property(get_Value, None)
    WarningText = property(get_WarningText, put_WarningText)
class PrintTaskOptionChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionChangedEventArgs
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintTaskOptionChangedEventArgs'
    @winrt_mixinmethod
    def get_OptionId(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionChangedEventArgs) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    OptionId = property(get_OptionId, None)
class PrintTaskOptionDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetails
    _classid_ = 'Windows.Graphics.Printing.OptionDetails.PrintTaskOptionDetails'
    @winrt_mixinmethod
    def get_Options(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetails) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Graphics.Printing.OptionDetails.IPrintOptionDetails]: ...
    @winrt_mixinmethod
    def CreateItemListOption(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetails, optionId: WinRT_String, displayName: WinRT_String) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintCustomItemListOptionDetails: ...
    @winrt_mixinmethod
    def CreateTextOption(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetails, optionId: WinRT_String, displayName: WinRT_String) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintCustomTextOptionDetails: ...
    @winrt_mixinmethod
    def add_OptionChanged(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetails, eventHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Printing.OptionDetails.PrintTaskOptionDetails, win32more.Windows.Graphics.Printing.OptionDetails.PrintTaskOptionChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_OptionChanged(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetails, eventCookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_BeginValidation(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetails, eventHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Graphics.Printing.OptionDetails.PrintTaskOptionDetails, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_BeginValidation(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetails, eventCookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def GetPageDescription(self: win32more.Windows.Graphics.Printing.IPrintTaskOptionsCore, jobPageNumber: UInt32) -> win32more.Windows.Graphics.Printing.PrintPageDescription: ...
    @winrt_mixinmethod
    def get_DisplayedOptions(self: win32more.Windows.Graphics.Printing.IPrintTaskOptionsCoreUIConfiguration) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    @winrt_mixinmethod
    def CreateToggleOption(self: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetails2, optionId: WinRT_String, displayName: WinRT_String) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintCustomToggleOptionDetails: ...
    @winrt_classmethod
    def GetFromPrintTaskOptions(cls: win32more.Windows.Graphics.Printing.OptionDetails.IPrintTaskOptionDetailsStatic, printTaskOptions: win32more.Windows.Graphics.Printing.PrintTaskOptions) -> win32more.Windows.Graphics.Printing.OptionDetails.PrintTaskOptionDetails: ...
    DisplayedOptions = property(get_DisplayedOptions, None)
    Options = property(get_Options, None)
    OptionChanged = event()
    BeginValidation = event()


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.UI.UIAutomation
import win32more.Windows.Win32.System.WinRT
class AutomationConnection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.UIAutomation.IAutomationConnection
    _classid_ = 'Windows.UI.UIAutomation.AutomationConnection'
    @winrt_mixinmethod
    def get_IsRemoteSystem(self: win32more.Windows.UI.UIAutomation.IAutomationConnection) -> Boolean: ...
    @winrt_mixinmethod
    def get_AppUserModelId(self: win32more.Windows.UI.UIAutomation.IAutomationConnection) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ExecutableFileName(self: win32more.Windows.UI.UIAutomation.IAutomationConnection) -> WinRT_String: ...
    AppUserModelId = property(get_AppUserModelId, None)
    ExecutableFileName = property(get_ExecutableFileName, None)
    IsRemoteSystem = property(get_IsRemoteSystem, None)
class AutomationConnectionBoundObject(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.UIAutomation.IAutomationConnectionBoundObject
    _classid_ = 'Windows.UI.UIAutomation.AutomationConnectionBoundObject'
    @winrt_mixinmethod
    def get_Connection(self: win32more.Windows.UI.UIAutomation.IAutomationConnectionBoundObject) -> win32more.Windows.UI.UIAutomation.AutomationConnection: ...
    Connection = property(get_Connection, None)
class AutomationElement(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.UIAutomation.IAutomationElement
    _classid_ = 'Windows.UI.UIAutomation.AutomationElement'
    @winrt_mixinmethod
    def get_IsRemoteSystem(self: win32more.Windows.UI.UIAutomation.IAutomationElement) -> Boolean: ...
    @winrt_mixinmethod
    def get_AppUserModelId(self: win32more.Windows.UI.UIAutomation.IAutomationElement) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ExecutableFileName(self: win32more.Windows.UI.UIAutomation.IAutomationElement) -> WinRT_String: ...
    AppUserModelId = property(get_AppUserModelId, None)
    ExecutableFileName = property(get_ExecutableFileName, None)
    IsRemoteSystem = property(get_IsRemoteSystem, None)
class AutomationTextRange(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.UIAutomation.IAutomationTextRange
    _classid_ = 'Windows.UI.UIAutomation.AutomationTextRange'
class IAutomationConnection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.UIAutomation.IAutomationConnection'
    _iid_ = Guid('{aad262ed-0ef4-5d43-97be-a834e27b65b9}')
    @winrt_commethod(6)
    def get_IsRemoteSystem(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_AppUserModelId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_ExecutableFileName(self) -> WinRT_String: ...
    AppUserModelId = property(get_AppUserModelId, None)
    ExecutableFileName = property(get_ExecutableFileName, None)
    IsRemoteSystem = property(get_IsRemoteSystem, None)
class IAutomationConnectionBoundObject(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.UIAutomation.IAutomationConnectionBoundObject'
    _iid_ = Guid('{5e8558fb-ca52-5b65-9830-dd2905816093}')
    @winrt_commethod(6)
    def get_Connection(self) -> win32more.Windows.UI.UIAutomation.AutomationConnection: ...
    Connection = property(get_Connection, None)
class IAutomationElement(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.UIAutomation.IAutomationElement'
    _iid_ = Guid('{a1898370-2c07-56fd-993f-61a72a08058c}')
    @winrt_commethod(6)
    def get_IsRemoteSystem(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_AppUserModelId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_ExecutableFileName(self) -> WinRT_String: ...
    AppUserModelId = property(get_AppUserModelId, None)
    ExecutableFileName = property(get_ExecutableFileName, None)
    IsRemoteSystem = property(get_IsRemoteSystem, None)
class IAutomationTextRange(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.UIAutomation.IAutomationTextRange'
    _iid_ = Guid('{7e101b65-40d3-5994-85a9-0a0cb9a4ec98}')
UIAutomationContract: UInt32 = 131072


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.AI.MachineLearning.WinML
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Direct3D12
import win32more.Windows.Win32.System.Com
WINML_TENSOR_DIMENSION_COUNT_MAX: UInt32 = 4
@winfunctype('winml.dll')
def WinMLCreateRuntime(runtime: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.IWinMLRuntime)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('windows.ai.machinelearning.dll')
def MLCreateOperatorRegistry(registry: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.IMLOperatorRegistry)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMLOperatorAttributes(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4b1b1759-ec40-466c-aab4-beb5347fd24c}')
    @commethod(3)
    def GetAttributeElementCount(self, name: win32more.Windows.Win32.Foundation.PSTR, type: win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorAttributeType, elementCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetAttribute(self, name: win32more.Windows.Win32.Foundation.PSTR, type: win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorAttributeType, elementCount: UInt32, elementByteSize: UIntPtr, value: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetStringAttributeElementLength(self, name: win32more.Windows.Win32.Foundation.PSTR, elementIndex: UInt32, attributeElementByteSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetStringAttributeElement(self, name: win32more.Windows.Win32.Foundation.PSTR, elementIndex: UInt32, attributeElementByteSize: UInt32, attributeElement: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMLOperatorKernel(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{11c4b4a0-b467-4eaa-a1a6-b961d8d0ed79}')
    @commethod(3)
    def Compute(self, context: win32more.Windows.Win32.AI.MachineLearning.WinML.IMLOperatorKernelContext) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMLOperatorKernelContext(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{82536a28-f022-4769-9d3f-8b278f84c0c3}')
    @commethod(3)
    def GetInputTensor(self, inputIndex: UInt32, tensor: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.IMLOperatorTensor)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetOutputTensor(self, outputIndex: UInt32, dimensionCount: UInt32, dimensionSizes: POINTER(UInt32), tensor: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.IMLOperatorTensor)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetOutputTensor(self, outputIndex: UInt32, tensor: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.IMLOperatorTensor)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def AllocateTemporaryData(self, size: UIntPtr, data: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetExecutionInterface(self, executionObject: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> Void: ...
class IMLOperatorKernelCreationContext(ComPtr):
    extends: win32more.Windows.Win32.AI.MachineLearning.WinML.IMLOperatorAttributes
    _iid_ = Guid('{5459b53d-a0fc-4665-addd-70171ef7e631}')
    @commethod(7)
    def GetInputCount(self) -> UInt32: ...
    @commethod(8)
    def GetOutputCount(self) -> UInt32: ...
    @commethod(9)
    def IsInputValid(self, inputIndex: UInt32) -> Boolean: ...
    @commethod(10)
    def IsOutputValid(self, outputIndex: UInt32) -> Boolean: ...
    @commethod(11)
    def GetInputEdgeDescription(self, inputIndex: UInt32, edgeDescription: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorEdgeDescription)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetOutputEdgeDescription(self, outputIndex: UInt32, edgeDescription: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorEdgeDescription)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def HasTensorShapeDescription(self) -> Boolean: ...
    @commethod(14)
    def GetTensorShapeDescription(self, shapeDescription: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.IMLOperatorTensorShapeDescription)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetExecutionInterface(self, executionObject: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> Void: ...
class IMLOperatorKernelFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ef15ad6f-0dc9-4908-ab35-a575a30dfbf8}')
    @commethod(3)
    def CreateKernel(self, context: win32more.Windows.Win32.AI.MachineLearning.WinML.IMLOperatorKernelCreationContext, kernel: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.IMLOperatorKernel)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMLOperatorRegistry(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{2af9dd2d-b516-4672-9ab5-530c208493ad}')
    @commethod(3)
    def RegisterOperatorSetSchema(self, operatorSetId: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorSetId), baselineVersion: Int32, schema: POINTER(POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorSchemaDescription)), schemaCount: UInt32, typeInferrer: win32more.Windows.Win32.AI.MachineLearning.WinML.IMLOperatorTypeInferrer, shapeInferrer: win32more.Windows.Win32.AI.MachineLearning.WinML.IMLOperatorShapeInferrer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def RegisterOperatorKernel(self, operatorKernel: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorKernelDescription), operatorKernelFactory: win32more.Windows.Win32.AI.MachineLearning.WinML.IMLOperatorKernelFactory, shapeInferrer: win32more.Windows.Win32.AI.MachineLearning.WinML.IMLOperatorShapeInferrer) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMLOperatorShapeInferenceContext(ComPtr):
    extends: win32more.Windows.Win32.AI.MachineLearning.WinML.IMLOperatorAttributes
    _iid_ = Guid('{105b6b29-5408-4a68-9959-09b5955a3492}')
    @commethod(7)
    def GetInputCount(self) -> UInt32: ...
    @commethod(8)
    def GetOutputCount(self) -> UInt32: ...
    @commethod(9)
    def IsInputValid(self, inputIndex: UInt32) -> Boolean: ...
    @commethod(10)
    def IsOutputValid(self, outputIndex: UInt32) -> Boolean: ...
    @commethod(11)
    def GetInputEdgeDescription(self, inputIndex: UInt32, edgeDescription: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorEdgeDescription)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetInputTensorDimensionCount(self, inputIndex: UInt32, dimensionCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetInputTensorShape(self, inputIndex: UInt32, dimensionCount: UInt32, dimensions: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def SetOutputTensorShape(self, outputIndex: UInt32, dimensionCount: UInt32, dimensions: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMLOperatorShapeInferrer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{540be5be-a6c9-40ee-83f6-d2b8b40a7798}')
    @commethod(3)
    def InferOutputShapes(self, context: win32more.Windows.Win32.AI.MachineLearning.WinML.IMLOperatorShapeInferenceContext) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMLOperatorTensor(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7fe41f41-f430-440e-aece-54416dc8b9db}')
    @commethod(3)
    def GetDimensionCount(self) -> UInt32: ...
    @commethod(4)
    def GetShape(self, dimensionCount: UInt32, dimensions: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetTensorDataType(self) -> win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorTensorDataType: ...
    @commethod(6)
    def IsCpuData(self) -> Boolean: ...
    @commethod(7)
    def IsDataInterface(self) -> Boolean: ...
    @commethod(8)
    def GetData(self) -> VoidPtr: ...
    @commethod(9)
    def GetDataInterface(self, dataInterface: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> Void: ...
class IMLOperatorTensorShapeDescription(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{f20e8cbe-3b28-4248-be95-f96fbc6e4643}')
    @commethod(3)
    def GetInputTensorDimensionCount(self, inputIndex: UInt32, dimensionCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetInputTensorShape(self, inputIndex: UInt32, dimensionCount: UInt32, dimensions: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def HasOutputShapeDescription(self) -> Boolean: ...
    @commethod(6)
    def GetOutputTensorDimensionCount(self, outputIndex: UInt32, dimensionCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetOutputTensorShape(self, outputIndex: UInt32, dimensionCount: UInt32, dimensions: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMLOperatorTypeInferenceContext(ComPtr):
    extends: win32more.Windows.Win32.AI.MachineLearning.WinML.IMLOperatorAttributes
    _iid_ = Guid('{ec893bb1-f938-427b-8488-c8dcf775f138}')
    @commethod(7)
    def GetInputCount(self) -> UInt32: ...
    @commethod(8)
    def GetOutputCount(self) -> UInt32: ...
    @commethod(9)
    def IsInputValid(self, inputIndex: UInt32) -> Boolean: ...
    @commethod(10)
    def IsOutputValid(self, outputIndex: UInt32) -> Boolean: ...
    @commethod(11)
    def GetInputEdgeDescription(self, inputIndex: UInt32, edgeDescription: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorEdgeDescription)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetOutputEdgeDescription(self, outputIndex: UInt32, edgeDescription: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorEdgeDescription)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IMLOperatorTypeInferrer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{781aeb48-9bcb-4797-bf77-8bf455217beb}')
    @commethod(3)
    def InferOutputTypes(self, context: win32more.Windows.Win32.AI.MachineLearning.WinML.IMLOperatorTypeInferenceContext) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWinMLEvaluationContext(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{95848f9e-583d-4054-af12-916387cd8426}')
    @commethod(3)
    def BindValue(self, pDescriptor: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_BINDING_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetValueByName(self, Name: win32more.Windows.Win32.Foundation.PWSTR, pDescriptor: POINTER(POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_BINDING_DESC))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Clear(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWinMLModel(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e2eeb6a9-f31f-4055-a521-e30b5b33664a}')
    @commethod(3)
    def GetDescription(self, ppDescription: POINTER(POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_MODEL_DESC))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def EnumerateMetadata(self, Index: UInt32, pKey: POINTER(win32more.Windows.Win32.Foundation.PWSTR), pValue: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def EnumerateModelInputs(self, Index: UInt32, ppInputDescriptor: POINTER(POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_VARIABLE_DESC))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def EnumerateModelOutputs(self, Index: UInt32, ppOutputDescriptor: POINTER(POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_VARIABLE_DESC))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWinMLRuntime(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a0425329-40ae-48d9-bce3-829ef7b8a41a}')
    @commethod(3)
    def LoadModel(self, Path: win32more.Windows.Win32.Foundation.PWSTR, ppModel: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.IWinMLModel)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateEvaluationContext(self, device: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Device, ppContext: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.IWinMLEvaluationContext)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def EvaluateModel(self, pContext: win32more.Windows.Win32.AI.MachineLearning.WinML.IWinMLEvaluationContext) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWinMLRuntimeFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a807b84d-4ae5-4bc0-a76a-941aa246bd41}')
    @commethod(3)
    def CreateRuntime(self, RuntimeType: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_RUNTIME_TYPE, ppRuntime: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.IWinMLRuntime)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class MLOperatorAttribute(Structure):
    name: win32more.Windows.Win32.Foundation.PSTR
    type: win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorAttributeType
    required: Byte
class MLOperatorAttributeNameValue(Structure):
    name: win32more.Windows.Win32.Foundation.PSTR
    type: win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorAttributeType
    valueCount: UInt32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        reserved: VoidPtr
        ints: POINTER(Int64)
        strings: POINTER(POINTER(SByte))
        floats: POINTER(Single)
class MLOperatorAttributeType(Enum, UInt32):
    Undefined = 0
    Float = 2
    Int = 3
    String = 4
    FloatArray = 7
    IntArray = 8
    StringArray = 9
class MLOperatorEdgeDescription(Structure):
    edgeType: win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorEdgeType
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        reserved: UInt64
        tensorDataType: win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorTensorDataType
class MLOperatorEdgeType(Enum, UInt32):
    Undefined = 0
    Tensor = 1
class MLOperatorEdgeTypeConstraint(Structure):
    typeLabel: win32more.Windows.Win32.Foundation.PSTR
    allowedTypes: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorEdgeDescription)
    allowedTypeCount: UInt32
class MLOperatorExecutionType(Enum, UInt32):
    Undefined = 0
    Cpu = 1
    D3D12 = 2
class MLOperatorKernelDescription(Structure):
    domain: win32more.Windows.Win32.Foundation.PSTR
    name: win32more.Windows.Win32.Foundation.PSTR
    minimumOperatorSetVersion: Int32
    executionType: win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorExecutionType
    typeConstraints: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorEdgeTypeConstraint)
    typeConstraintCount: UInt32
    defaultAttributes: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorAttributeNameValue)
    defaultAttributeCount: UInt32
    options: win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorKernelOptions
    executionOptions: UInt32
class MLOperatorKernelOptions(Enum, UInt32):
    None_ = 0
    AllowDynamicInputShapes = 1
class MLOperatorParameterOptions(Enum, UInt32):
    Single = 0
    Optional = 1
    Variadic = 2
class MLOperatorSchemaDescription(Structure):
    name: win32more.Windows.Win32.Foundation.PSTR
    operatorSetVersionAtLastChange: Int32
    inputs: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorSchemaEdgeDescription)
    inputCount: UInt32
    outputs: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorSchemaEdgeDescription)
    outputCount: UInt32
    typeConstraints: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorEdgeTypeConstraint)
    typeConstraintCount: UInt32
    attributes: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorAttribute)
    attributeCount: UInt32
    defaultAttributes: POINTER(win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorAttributeNameValue)
    defaultAttributeCount: UInt32
class MLOperatorSchemaEdgeDescription(Structure):
    options: win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorParameterOptions
    typeFormat: win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorSchemaEdgeTypeFormat
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        reserved: VoidPtr
        typeLabel: win32more.Windows.Win32.Foundation.PSTR
        edgeDescription: win32more.Windows.Win32.AI.MachineLearning.WinML.MLOperatorEdgeDescription
class MLOperatorSchemaEdgeTypeFormat(Enum, Int32):
    EdgeDescription = 0
    Label = 1
class MLOperatorSetId(Structure):
    domain: win32more.Windows.Win32.Foundation.PSTR
    version: Int32
class MLOperatorTensorDataType(Enum, UInt32):
    Undefined = 0
    Float = 1
    UInt8 = 2
    Int8 = 3
    UInt16 = 4
    Int16 = 5
    Int32 = 6
    Int64 = 7
    String = 8
    Bool = 9
    Float16 = 10
    Double = 11
    UInt32 = 12
    UInt64 = 13
    Complex64 = 14
    Complex128 = 15
class WINML_BINDING_DESC(Structure):
    Name: win32more.Windows.Win32.Foundation.PWSTR
    BindType: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_BINDING_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Tensor: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_BINDING_DESC
        Sequence: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_SEQUENCE_BINDING_DESC
        Map: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_MAP_BINDING_DESC
        Image: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_IMAGE_BINDING_DESC
        Resource: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_RESOURCE_BINDING_DESC
WINML_BINDING_TYPE = Int32
WINML_BINDING_UNDEFINED: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_BINDING_TYPE = 0
WINML_BINDING_TENSOR: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_BINDING_TYPE = 1
WINML_BINDING_SEQUENCE: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_BINDING_TYPE = 2
WINML_BINDING_MAP: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_BINDING_TYPE = 3
WINML_BINDING_IMAGE: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_BINDING_TYPE = 4
WINML_BINDING_RESOURCE: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_BINDING_TYPE = 5
WINML_FEATURE_TYPE = Int32
WINML_FEATURE_UNDEFINED: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_FEATURE_TYPE = 0
WINML_FEATURE_TENSOR: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_FEATURE_TYPE = 1
WINML_FEATURE_SEQUENCE: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_FEATURE_TYPE = 2
WINML_FEATURE_MAP: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_FEATURE_TYPE = 3
WINML_FEATURE_IMAGE: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_FEATURE_TYPE = 4
class WINML_IMAGE_BINDING_DESC(Structure):
    ElementType: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE
    NumDimensions: UInt32
    pShape: POINTER(Int64)
    DataSize: UInt32
    pData: VoidPtr
class WINML_IMAGE_VARIABLE_DESC(Structure):
    ElementType: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE
    NumDimensions: UInt32
    pShape: POINTER(Int64)
class WINML_MAP_BINDING_DESC(Structure):
    ElementCount: UInt32
    KeyType: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE
    Anonymous1: _Anonymous1_e__Union
    Fields: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE
    Anonymous2: _Anonymous2_e__Union
    class _Anonymous1_e__Union(Union):
        pStringKeys: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
        pIntKeys: POINTER(Int64)
    class _Anonymous2_e__Union(Union):
        pStringFields: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
        pIntFields: POINTER(Int64)
        pFloatFields: POINTER(Single)
        pDoubleFields: POINTER(Double)
class WINML_MAP_VARIABLE_DESC(Structure):
    KeyType: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE
    Fields: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE
class WINML_MODEL_DESC(Structure):
    Author: win32more.Windows.Win32.Foundation.PWSTR
    Name: win32more.Windows.Win32.Foundation.PWSTR
    Domain: win32more.Windows.Win32.Foundation.PWSTR
    Description: win32more.Windows.Win32.Foundation.PWSTR
    Version: UIntPtr
class WINML_RESOURCE_BINDING_DESC(Structure):
    ElementType: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE
    NumDimensions: UInt32
    pShape: POINTER(Int64)
    pResource: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Resource
WINML_RUNTIME_TYPE = Int32
WINML_RUNTIME_CNTK: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_RUNTIME_TYPE = 0
class WINML_SEQUENCE_BINDING_DESC(Structure):
    ElementCount: UInt32
    ElementType: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        pStrings: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
        pInts: POINTER(Int64)
        pFloats: POINTER(Single)
        pDoubles: POINTER(Double)
class WINML_SEQUENCE_VARIABLE_DESC(Structure):
    ElementType: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE
class WINML_TENSOR_BINDING_DESC(Structure):
    DataType: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE
    NumDimensions: UInt32
    pShape: POINTER(Int64)
    DataSize: UInt32
    pData: VoidPtr
WINML_TENSOR_DATA_TYPE = Int32
WINML_TENSOR_UNDEFINED: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE = 0
WINML_TENSOR_FLOAT: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE = 1
WINML_TENSOR_UINT8: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE = 2
WINML_TENSOR_INT8: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE = 3
WINML_TENSOR_UINT16: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE = 4
WINML_TENSOR_INT16: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE = 5
WINML_TENSOR_INT32: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE = 6
WINML_TENSOR_INT64: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE = 7
WINML_TENSOR_STRING: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE = 8
WINML_TENSOR_BOOLEAN: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE = 9
WINML_TENSOR_FLOAT16: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE = 10
WINML_TENSOR_DOUBLE: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE = 11
WINML_TENSOR_UINT32: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE = 12
WINML_TENSOR_UINT64: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE = 13
WINML_TENSOR_COMPLEX64: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE = 14
WINML_TENSOR_COMPLEX128: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE = 15
class WINML_TENSOR_VARIABLE_DESC(Structure):
    ElementType: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_DATA_TYPE
    NumDimensions: UInt32
    pShape: POINTER(Int64)
class WINML_VARIABLE_DESC(Structure):
    Name: win32more.Windows.Win32.Foundation.PWSTR
    Description: win32more.Windows.Win32.Foundation.PWSTR
    FeatureType: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_FEATURE_TYPE
    Required: win32more.Windows.Win32.Foundation.BOOL
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Tensor: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_TENSOR_VARIABLE_DESC
        Sequence: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_SEQUENCE_VARIABLE_DESC
        Map: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_MAP_VARIABLE_DESC
        Image: win32more.Windows.Win32.AI.MachineLearning.WinML.WINML_IMAGE_VARIABLE_DESC


make_ready(__name__)
